#include "parsertest.h"

#include <QTest>

#include "../parsesession.h"
#include "../editorintegrator.h"

QTEST_MAIN(erlang::TestParser)

namespace erlang
{

TestParser::TestParser()
{
}

void TestParser::functionDeclaration()
{
    erlang::ParseSession session;
    session.setContents("my_func(VariableA, atom_b) -> ok.");
    FormAst* ast = 0;

    QVERIFY(session.parse(&ast));
}

void TestParser::functionClausesDeclaration()
{
    erlang::ParseSession session;
    session.setContents("my_func(VariableA, atom_b) -> ok;  my_func(VariableA, atom_c) -> then.");
    FormAst* ast = 0;

    QVERIFY(session.parse(&ast));
}

void TestParser::list()
{
    {
        erlang::ParseSession session;
        session.setContents("test_list() -> X = [].");
        FormAst* ast = 0;

        QVERIFY(session.parse(&ast));
    }

    {
        erlang::ParseSession session;
        FormAst* ast = 0;
        session.setContents("test_list() -> X = []].");
        QVERIFY(session.parse(&ast) == false);
    }

    {
        erlang::ParseSession session;
        FormAst* ast = 0;

        session.setContents("test_list() -> X = [[]].");
        QVERIFY(session.parse(&ast) == true);
    }
}

void TestParser::testNumeric()
{
    {
        erlang::ParseSession session;
        session.setContents("test_list() -> X = 1.");
        FormAst* ast = 0;

        QVERIFY(session.parse(&ast));
    }
    
    {
        erlang::ParseSession session;
        session.setContents("test_list() -> X = 11234512345235634745745623543244523.");
        FormAst* ast = 0;

        QVERIFY(session.parse(&ast));
    }
    
    {
        erlang::ParseSession session;
        session.setContents("test_list() -> X = 1..");
        FormAst* ast = 0;

        QVERIFY(session.parse(&ast) == false);
    }
    
}

}
